%bcond_with bootstrap
%bcond_with ivy

%global python_prefix python3
%global python_interpreter %{?__python3}%{!?__python3:dummy}

%global default_jdk %{_prefix}/lib/jvm/java-17
%global default_jre %{_prefix}/lib/jvm/jre-17

%global maven_home %{_datadir}/xmvn

Summary:        Macros and scripts for Java packaging support
Name:           javapackages-tools
Version:        6.1.0
Release:        8%{?dist}
License:        BSD
URL:            https://github.com/fedora-java/javapackages
Source0:        https://github.com/fedora-java/javapackages/archive/%{version}.tar.gz
Source1:        javapackages-config.json
Source2:        toolchains-openjdk8.xml
Source3:        toolchains-openjdk11.xml
Source4:        toolchains-openjdk17.xml

Patch5000:      0001-Except-coverage-AttributeError-abnormal.patch

BuildRequires:  coreutils
BuildRequires:  which
BuildRequires:  make
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  lua
BuildRequires:  %{python_prefix}-devel
BuildRequires:  %{python_prefix}-lxml
BuildRequires:  %{python_prefix}-setuptools
BuildRequires:  %{python_prefix}-pytest

BuildArch:      noarch

Requires:       javapackages-filesystem = %{version}-%{release}
Requires:       coreutils
Requires:       findutils
Requires:       which
Requires:       java-17-headless

Provides:       jpackage-utils = %{version}-%{release}

%description
This package provides macros and scripts to support Java packaging.

%package -n javapackages-filesystem
Summary:        Java packages filesystem layout
Provides:       eclipse-filesystem = %{version}-%{release}

%description -n javapackages-filesystem
This package provides some basic directories into which Java packages
install their content.

%package -n maven-local
Summary:        Macros and scripts for Maven packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
%if %{with bootstrap}
Requires:       javapackages-bootstrap >= 1.7.1
%else
Requires:       xmvn-minimal
Requires:       mvn(org.fedoraproject.xmvn:xmvn-mojo)
Requires:       mvn(org.apache.maven.plugins:maven-compiler-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-jar-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-resources-plugin)
Requires:       mvn(org.apache.maven.plugins:maven-surefire-plugin)
%endif

%description -n maven-local
This package provides macros and scripts to support packaging Maven artifacts.

%if %{with ivy}
%package -n ivy-local
Summary:        Local mode for Apache Ivy
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       apache-ivy >= 2.3.0-8
Requires:       xmvn-connector-ivy

%description -n ivy-local
This package implements local mode for Apache Ivy, which allows
artifact resolution using XMvn resolver.
%endif

%package -n %{python_prefix}-javapackages
Summary:        Module for handling various files for Java packaging
Requires:       %{python_prefix}-lxml

%description -n %{python_prefix}-javapackages
Module for handling, querying and manipulating of various files for Java
packaging in Linux distributions

%package -n javapackages-local
Summary:        Non-essential macros and scripts for Java packaging support
Requires:       javapackages-common = %{version}-%{release}
Requires:       java-17-devel
%if %{with bootstrap}
Requires:       javapackages-bootstrap >= 1.7.1
%else
Requires:       xmvn-tools
%endif

%description -n javapackages-local
This package provides non-essential macros and scripts to support Java packaging.

%package -n javapackages-generators
Summary:        RPM dependency generators for Java packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       %{python_prefix}-javapackages = %{version}-%{release}
Requires:       %{python_interpreter}

%description -n javapackages-generators
RPM dependency generators to support Java packaging.

%package -n javapackages-common
Summary:        Non-essential macros and scripts for Java packaging support
Requires:       javapackages-generators = %{version}-%{release}

%description -n javapackages-common
This package provides non-essential, but commonly used macros and
scripts to support Java packaging.

%package -n javapackages-extra
Summary:        Rarely-used macros and scripts for Java packaging support
Requires:       javapackages-generators = %{version}-%{release}
Requires:       lua

%description -n javapackages-extra
This package provides rarely-used and obsolete macros and scripts to
support Java packaging.

%package -n maven-local-openjdk8
Summary:        JDK 8 toolchain for XMvn
RemovePathPostfixes: -openjdk8
Requires:       maven-local
Requires:       java-1.8.0-devel
Conflicts:      maven-local-openjdk11
Conflicts:      maven-local-openjdk17

%description -n maven-local-openjdk8
JDK 8 toolchain for XMvn

%package -n maven-local-openjdk11
Summary:        JDK 11 toolchain for XMvn
RemovePathPostfixes: -openjdk11
Requires:       maven-local
Requires:       java-11-devel
Conflicts:      maven-local-openjdk8
Conflicts:      maven-local-openjdk17

%description -n maven-local-openjdk11
JDK 11 toolchain for XMvn

%package -n maven-local-openjdk17
Summary:        JDK 17 toolchain for XMvn
RemovePathPostfixes: -openjdk17
Requires:       maven-local
Requires:       java-17-devel
Conflicts:      maven-local-openjdk8
Conflicts:      maven-local-openjdk11

%description -n maven-local-openjdk17
JDK 17 toolchain for XMvn



%prep
%autosetup -n javapackages-%{version} -p1

sed -i /javapackages-metadata.xml/d install



%build
%configure --pyinterpreter=%{python_interpreter} \
    --default_jdk=%{default_jdk} --default_jre=%{default_jre} \
    --rpmmacrodir=%{rpmmacrodir}

./build



%install
./install

sed -e 's/.[17]$/&*/' -i files-*

rm -rf %{buildroot}%{_bindir}/gradle-local
rm -rf %{buildroot}%{_datadir}/gradle-local
rm -rf %{buildroot}%{_mandir}/man7/gradle_build.7
%if %{without ivy}
rm -rf %{buildroot}%{_sysconfdir}/ivy
rm -rf %{buildroot}%{_sysconfdir}/ant.d
%endif

mkdir -p %{buildroot}%{maven_home}/conf/
cp -p %{SOURCE2} %{buildroot}%{maven_home}/conf/toolchains.xml-openjdk8
cp -p %{SOURCE3} %{buildroot}%{maven_home}/conf/toolchains.xml-openjdk11
cp -p %{SOURCE4} %{buildroot}%{maven_home}/conf/toolchains.xml-openjdk17

install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/java/javapackages-config.json



%check
./check



%files -f files-tools

%files -n javapackages-filesystem -f files-filesystem

%files -n javapackages-generators -f files-generators

%files -n javapackages-common -f files-common

%files -n javapackages-extra -f files-extra

%files -n javapackages-local

%files -n maven-local

%if %{with ivy}
%files -n ivy-local -f files-ivy
%endif

%files -n maven-local-openjdk8
%dir %{maven_home}/conf
%{maven_home}/conf/toolchains.xml-openjdk8

%files -n maven-local-openjdk11
%dir %{maven_home}/conf
%{maven_home}/conf/toolchains.xml-openjdk11

%files -n maven-local-openjdk17
%dir %{maven_home}/conf
%{maven_home}/conf/toolchains.xml-openjdk17

%files -n %{python_prefix}-javapackages -f files-python
%license LICENSE



%changelog
* Thu Sep 14 2023 kianli <kianli@tencent.com> - 6.1.0-8
- Fix test fail with python3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.1.0-7
- Rebuilt for OpenCloudOS Stream 23.09

* Mon May 22 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.1.0-6
- fixing test error

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.1.0-5
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.1.0-4
- closed bootstrap mode

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.1.0-3
- Rebuilt for OpenCloudOS Stream 23

* Fri Mar 31 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.1.0-2
- small fix

* Fri Mar 31 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.1.0-1
- updated to upstream 6.1.0
- changed default JDK version to 17

* Mon Mar 20 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.0.0-5
- small fix

* Mon Mar 20 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.0.0-4
- small fix

* Mon Mar 20 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.0.0-3
- non-bootstrap

* Mon Mar 20 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.0.0-2
- small fix

* Mon Mar 20 2023 Zhao Zhen <jeremiazhao@tencent.com> - 6.0.0-1
- initial

